<?php

/* --------------------------------------------------------------
   ContentServiceFactory.inc.php 2019-04-16
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class ContentServiceFactory
 *
 * This class represents a factory for content services
 *
 * @category   System
 * @package    Content
 */
class ContentServiceFactory implements ContentServiceFactoryInterface
{
    /**
     * CodeIgniter QueryBuilder
     *
     * @var CI_DB_query_builder
     */
    protected $queryBuilder;
    
    /**
     * Content repository
     *
     * @var ContentRepository
     */
    protected $repository;
    
    /**
     * Content write service
     *
     * @var ContentWriteService
     */
    protected $writeService;
    
    /**
     * Content writer
     *
     * @var ContentWriter
     */
    protected $writer;
    
    
    /**
     * ContentServiceFactory constructor
     *
     * @param CI_DB_query_builder $queryBuilder CodeIgniter QueryBuilder instance
     */
    public function __construct(CI_DB_query_builder $queryBuilder)
    {
        $this->queryBuilder = $queryBuilder;
    }
    
    
    /**
     * Return a content write service
     *
     * @return ContentWriteService
     */
    public function createWriteService()
    {
        if ($this->writeService === null) {
            $this->writeService = MainFactory::create(ContentWriteService::class, $this->repository());
        }
        
        return $this->writeService;
    }
    
    
    /**
     * Return a content repository
     *
     * @return ContentRepository
     */
    protected function repository()
    {
        if ($this->repository === null) {
            $this->repository = MainFactory::create(ContentRepository::class, $this->writer());
        }
        
        return $this->repository;
    }
    
    
    /**
     * Return a content writer
     *
     * @return ContentWriter
     */
    protected function writer()
    {
        if ($this->writer === null) {
            $this->writer = MainFactory::create(ContentWriter::class, $this->queryBuilder);
        }
        
        return $this->writer;
    }
}