<?php
/* --------------------------------------------------------------
   dependent.inc.php 2019-03-26
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

// check if current installed version is affected from invoice / packing slip number bug

$installedVersion = $this->query('SELECT `gm_value` 
									FROM `gm_configuration` 
									WHERE 
										`gm_key` = "INSTALLED_VERSION" AND 
										`gm_value` IN ("v3.10.3.0 (BETA1)", "v3.10.3.0", "v3.11.3.0 (BETA1)", "v3.11.3.0", "v3.12.0.0 (BETA1)", "v3.12.0.0", "v3.12.0.1")');

if(count($installedVersion))
{
	// i.e. v3.10.3.0 (BETA1) -> 3.10.3.0 beta1
	$installedVersion = strtolower(preg_replace('/[v\(\)]/', '', $installedVersion[0]['gm_value']));
	
	$installationDate = $this->query('SELECT `installation_date` 
										FROM `version_history` 
										WHERE `version` IN ("3.10.3.0 beta1", "3.10.3.0", "3.11.3.0 beta1", "3.11.3.0", "3.12.0.0 beta1", "3.12.0.0", "3.12.0.1")
										ORDER BY `installation_date` ASC
										LIMIT 1');
	
	if(count($installationDate))
	{
		// invoices
		
		$nextInvoiceId  = $this->query('SELECT `gm_value` FROM `gm_configuration` WHERE `gm_key` = "GM_NEXT_INVOICE_ID"');
		$invoicePattern = $this->query('SELECT `gm_value` FROM `gm_configuration` WHERE `gm_key` = "GM_INVOICE_ID"');
		
		$installationDate = $installationDate[0]['installation_date'];
		
		$invoices = $this->query('SELECT `invoice_number` 
									FROM `invoices` 
									WHERE `invoice_date` > "' . $installationDate . '"
									ORDER BY `invoice_date` DESC');
		
		$invoiceNumbers = [];
		
		foreach($invoices as $invoice)
		{
			
			$regex                = '/^' . str_replace('\{INVOICE_ID\}', '([0-9]+)',
			                                           preg_quote($invoicePattern[0]['gm_value'], '/'))
			                        . '(_STORNO)?$/';
			$invoiceIntegerNumber = preg_replace($regex, '$1', $invoice['invoice_number']);
			
			if(is_numeric($invoiceIntegerNumber) && $invoiceIntegerNumber == (int)$invoiceIntegerNumber)
			{
				$invoiceNumbers[] = (int)$invoiceIntegerNumber;
			}
		}
		
		sort($invoiceNumbers, SORT_NUMERIC);
		
		$highestNumber = array_pop($invoiceNumbers);
		
		if($highestNumber !== null && (int)$nextInvoiceId[0]['gm_value'] !== $highestNumber + 1)
		{
			$nextIdIsUnused = false;
			
			do
			{
				$nextInvoiceNumber = str_replace('{INVOICE_ID}', $highestNumber + 1, $invoicePattern[0]['gm_value']);
				
				$check = $this->query('SELECT `invoice_id` 
										FROM `invoices` 
										WHERE 
											`invoice_number` = "'
				                      . $this->coo_mysqli->real_escape_string($nextInvoiceNumber) . '"');
				if(!count($check))
				{
					$nextIdIsUnused = true;
				}
				else
				{
					$highestNumber++;
				}
			}
			while($nextIdIsUnused === false);
			
			$query     = 'UPDATE `gm_configuration`
							SET `gm_value` = "' . ($highestNumber + 1) . '"
							WHERE `gm_key` = "GM_NEXT_INVOICE_ID"';
			$t_success &= is_numeric($this->query($query));
		}
	}
	
	// packing slips
	
	$nextPackingSlipId  = $this->query('SELECT `gm_value` FROM `gm_configuration` WHERE `gm_key` = "GM_NEXT_PACKINGS_ID"');
	$packingSlipPattern = $this->query('SELECT `gm_value` FROM `gm_configuration` WHERE `gm_key` = "GM_PACKINGS_ID"');
	
	$packingSlips = $this->query('SELECT `number` 
									FROM `packing_slips` 
									WHERE `date` > "' . $installationDate . '"
									ORDER BY `date` DESC');
	
	$packingSlipNumbers = [];
	
	foreach($packingSlips as $packingSlip)
	{
		$regex                    = '/^' . str_replace('\{DELIVERY_ID\}', '([0-9]+)',
		                                               preg_quote($packingSlipPattern[0]['gm_value'], '/')) . '$/';
		$packingSlipIntegerNumber = preg_replace($regex, '$1', $packingSlip['number']);
		
		if(is_numeric($packingSlipIntegerNumber) && $packingSlipIntegerNumber == (int)$packingSlipIntegerNumber)
		{
			$packingSlipNumbers[] = (int)$packingSlipIntegerNumber;
		}
	}
	
	sort($packingSlipNumbers, SORT_NUMERIC);
	
	$highestNumber = array_pop($packingSlipNumbers);
	
	if($highestNumber !== null && (int)$nextPackingSlipId[0]['gm_value'] !== $highestNumber + 1)
	{
		$nextIdIsUnused = false;
		
		do
		{
			$nextPackingSlipNumber = str_replace('{DELIVERY_ID}', $highestNumber + 1,
			                                     $packingSlipPattern[0]['gm_value']);
			
			$check = $this->query('SELECT `packing_slip_id` 
									FROM `packing_slips` 
									WHERE 
										`number` = "'
			                      . $this->coo_mysqli->real_escape_string($nextPackingSlipNumber) . '"');
			if(!count($check))
			{
				$nextIdIsUnused = true;
			}
			else
			{
				$highestNumber++;
			}
		}
		while($nextIdIsUnused === false);
		
		$query     = 'UPDATE `gm_configuration`
						SET `gm_value` = "' . ($highestNumber + 1) . '"
						WHERE `gm_key` = "GM_NEXT_PACKINGS_ID"';
		$t_success &= is_numeric($this->query($query));
	}
}


